#!/usr/bin/env python3
import sys
from loveread import *

if __name__ == "__main__":
    urls=[]
    if len(sys.argv) > 1:
        urls = sys.argv[1:]
    else:
        urls=[input("Enter book url from loberead.ec: ")]
    
    for url in urls:
        download(url)
    


from setuptools import setup

setup(
    name="loveread",
    version="0.2.1.1",
    author="Vlad Havrylov",
    author_email="wladgavrilov@gmail.com",
    description="A brief description of your package",
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url="https://gitlab.com/wladgavrilov/loveread",
    packages=['loveread'],
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
    ],
)


import requests
from bs4 import BeautifulSoup

def test():
    return download("http://loveread.ec/read_book.php?id=70351", True)

def download(book_url, save=True, folder=""):
    base_url = "http://loveread.ec/read_book.php?id=%(id)s&p=%(page)s"
    ID = book_url.split("id=")[-1].split("&")[0]
    r = requests.get(base_url % {"id": ID, "page": 1})
    r.encoding = "Windows-1251"
    soup = BeautifulSoup(r.text, "html.parser")
    PAGES = int(soup.select(".navigation a")[-2].get_text())
    NAME = soup.select(".tb_read_book h2 a")[0].get_text()

    book = []
    for i in range(1, PAGES+1):
        url = base_url % {"id": ID, "page": i}
        print("downloading from ", url)
        r = requests.get(url)
        r.encoding = "Windows-1251"
        soup = BeautifulSoup(r.text, "html.parser")
        main = soup.select("p.MsoNormal")
        book.append(main[0].get_text() + "")
        # for elem in main:
        #     book.append(elem.get_text() + "///")

    handler = open(folder + NAME + ".txt", "w+")
    strBook = "\r\n\r\n".join(book)
    if save:
        for i in strBook:
            try:
                handler.write(i)
            except ValueError:
                handler.write("?")
                
    return strBook
